@@ -100,6 +100,7 @@ private void PrArgs( argc, argv )
 
 
 private void CheckErrs( n )
+  int n;
   {
     nerrs += n;
     if( nerrs > MAX_ERRS )
@@ -923,7 +924,7 @@ private int input_sim (simfile, has_param_file)
 	    case '|':
 		if (lineno > 1) break;
 		if (targc > 2) {
-		    double lmbd = atof(targv[2]) / 100.0;
+		    double lmbd = 100.0 / atof(targv[2]);
 
 		    if ((targc > 4) && (has_param_file < 0))
 		    {
